"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeLastVersion = exports.getLastVersion = exports.LastVersion = void 0;
const fs = require("fs-extra");
const messages = require("./Messages");
class LastVersion {
    constructor(version, cloudUrl, timestamp) {
        this.updatePeriodInHours = 8;
        this.version = version;
        this.cloudUrl = cloudUrl;
        this.timestamp = timestamp;
    }
    canUpdateApp() {
        const expirationDate = this.timestamp.getTime() + (this.updatePeriodInHours * 60 * 60 * 1000);
        if (expirationDate < new Date().getTime()) {
            return true;
        }
        return false;
    }
}
exports.LastVersion = LastVersion;
async function getLastVersion(fileName) {
    if (!(await fs.pathExists(fileName))) {
        throw new Error(messages.versionForRunNotFound);
    }
    try {
        var lastVersion = JSON.parse(await fs.readFile(fileName, "utf-8"));
        return new LastVersion(lastVersion.version, lastVersion.cloudUrl, new Date(lastVersion.timestamp));
    }
    catch {
        throw new Error(messages.versionForRunNotFound);
    }
}
exports.getLastVersion = getLastVersion;
async function writeLastVersion(lastVersion, fileName) {
    try {
        await fs.writeFile(fileName, JSON.stringify(lastVersion));
    }
    catch {
        console.warn(messages.cannotSaveLastVersion);
    }
}
exports.writeLastVersion = writeLastVersion;
