"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const downloader = require("./Downloader");
const messages = require("./Messages");
const util = require("./Util");
const versionManager = require("./VersionManager");
const child_process = require("child_process");
const fs = require("fs-extra");
const os = require("os");
const path = require("path");
const Downloader_1 = require("./Downloader");
const Util_1 = require("./Util");
const runFile = "swarm.dll";
const runDotNet = "dotnet";
const homeDir = path.join(os.homedir(), ".swarm");
const lastVersionFileName = path.join(homeDir, ".lastversion");
const platform = util.getPlatform();
main();
async function main() {
    try {
        await work();
    }
    catch (error) {
        console.error(error.message);
        process.exit(1);
    }
}
async function work() {
    var _a;
    await checkOrCreateDir(homeDir);
    var lastVersion = await versionManager.getLastVersion(lastVersionFileName);
    if (lastVersion.canUpdateApp()) {
        try {
            console.info(messages.checkingLatestVersion);
            lastVersion = await downloader.checkOrDownloadLatestVersion(lastVersion.cloudUrl, (_a = lastVersion === null || lastVersion === void 0 ? void 0 : lastVersion.version) !== null && _a !== void 0 ? _a : null, homeDir, platform, runFile);
        }
        catch (error) {
            if (error instanceof Downloader_1.DownloadError) {
                console.error(error.message);
            }
            else {
                console.error(messages.cannotDownloadLatestVersion);
            }
            if (lastVersion) {
                lastVersion.timestamp = new Date();
            }
        }
        if (lastVersion) {
            await versionManager.writeLastVersion(lastVersion, lastVersionFileName);
            console.info((0, Util_1.formatString)(messages.running, path.join(homeDir, lastVersion.version, runFile)));
        }
    }
    if (!lastVersion) {
        throw new Error(messages.versionForRunNotFound);
    }
    const command = runDotNet + " " + path.join(homeDir, lastVersion.version, runFile);
    run(command);
}
async function checkOrCreateDir(dir) {
    if (!(await fs.pathExists(dir))) {
        try {
            console.info((0, Util_1.formatString)(messages.creatingParentDir, dir));
            await fs.mkdirp(dir);
        }
        catch {
            throw new Error((0, Util_1.formatString)(messages.cannotCreateParentDir, dir));
        }
    }
}
function run(path) {
    var swarmProcess = child_process.spawn(path, process.argv.slice(2), { stdio: "inherit", shell: true });
    swarmProcess.on("exit", (code) => {
        process.exit(code);
    });
}
